@@ -11,6 +11,7 @@ _Optimization = misc_utils._Optimization
 _Yield = misc_utils._Yield
 _GlobalDefinitions = misc_utils._GlobalDefinitions
 _CommonTools = common_utils._CommonTools
+_OutputEquations = misc_utils._OutputEquations
 #
 def establish_link(version_str: str ='', clsid_str:str ='') -> object:
     '''
@@ -75,7 +76,7 @@ def establish_link(version_str: str ='', clsid_str:str ='') -> object:
     return awrde
     #
 class Project(_Graphs, _Schematics, _SystemDiagrams, _DataFiles, _Optimization, _GlobalDefinitions,
-              _CommonTools, _Yield):
+              _CommonTools, _Yield, _OutputEquations):
     ''' 
     Highest level class in pyawr_utils. User interface to all classes,methods, properties,
     etc. are through the Project class
@@ -94,7 +95,8 @@ class Project(_Graphs, _Schematics, _SystemDiagrams, _DataFiles, _Optimization,
             _DataFiles.__init__(self, awrde)
             _Optimization.__init__(self, awrde)
             _Yield.__init__(self, awrde)
-            _GlobalDefinitions.__init__(self, awrde)            
+            _GlobalDefinitions.__init__(self, awrde)
+            _OutputEquations.__init__(self, awrde)
         #end if
         _CommonTools.__init__(self, awrde)
         self._options_blacklist()
@@ -114,6 +116,7 @@ class Project(_Graphs, _Schematics, _SystemDiagrams, _DataFiles, _Optimization,
                       'data files'
                       'global definitions'
                       'optimization'
+                      'output equations'
         '''
         if not isinstance(which_initialization, str):
             raise TypeError('which_initialization must be string type')
@@ -136,25 +139,29 @@ class Project(_Graphs, _Schematics, _SystemDiagrams, _DataFiles, _Optimization,
         elif which_initialization == 'optimization':
             Initialization_dict['optimization'] = True
         elif which_initialization == 'data files':
-            Initialization_dict['data files'] = True        
+            Initialization_dict['data files'] = True
+        elif which_initialization == 'output equations':
+            Initialization_dict['output equations'] = True         
         else:
             raise RuntimeError('Invalid which_initialization: '+which_initialization)
         #end if
         #
         try:
             for key_name, do_it in Initialization_dict.items():
-                if key_name=='schematics' and do_it:
+                if key_name == 'schematics' and do_it:
                     _Schematics.__init__(self, self.awrde.Project)
-                elif key_name=='system diagrams' and do_it:
+                elif key_name == 'system diagrams' and do_it:
                     _SystemDiagrams.__init__(self, self.awrde)
-                elif key_name=='graphs' and do_it:
+                elif key_name == 'graphs' and do_it:
                     _Graphs.__init__(self, self.awrde)
-                elif key_name=='global definitions' and do_it:
+                elif key_name == 'global definitions' and do_it:
                     _GlobalDefinitions.__init__(self, self.awrde)
-                elif key_name=='optimization' and do_it:
+                elif key_name == 'optimization' and do_it:
                     _Optimization.__init__(self, self.awrde)
-                elif key_name=='data files' and do_it:
-                    _DataFiles.__init__(self, self.awrde)            
+                elif key_name == 'data files' and do_it:
+                    _DataFiles.__init__(self, self.awrde) 
+                elif key_name == 'output equations' and do_it:
+                    _OutputEquations.__init__(self, self.awrde)
                 #end if
             #end for
         except:
