@@ -1514,7 +1514,7 @@ class _GlobalDefinitions():
     '''
     Methods for collection of Global Definitions Documents
     
-     Parameters
+    Parameters
     ----------
     awrde: The AWRDE object returned from awrde_utils.establish_link()
     '''
@@ -1522,7 +1522,7 @@ class _GlobalDefinitions():
         self.awrde = awrde
         #
     def _build_global_defs_dict(self):#--------------------------------
-        '''Create list of all graph names in project
+        '''Create dictionary of all graph names in the project
     
         Parameters
         ----------
@@ -1549,11 +1549,11 @@ class _GlobalDefinitions():
     @property
     def global_definitions_list(self) -> list:#-----------------------------------
         '''returns global definition documents list of names'''
-        gloabal_defs_list = list()
+        global_defs_list = list()
         for gd in self.awrde.Project.GlobalDefinitionDocuments:
-            gloabal_defs_list.append(gd.Name)
+            global_defs_list.append(gd.Name)
         #end for
-        return gloabal_defs_list
+        return global_defs_list
         #
     def add_global_definitions_document(self, global_def_doc_name: str):#-----------------------------------
         gd_doc_exists = False
@@ -1562,6 +1562,7 @@ class _GlobalDefinitions():
                 gd_doc_exists = True
             #end if
         #end for
+        #
         if gd_doc_exists:
             YesNo = messagebox.askyesno('Add Global Definition Document','Global Definition Document ' + global_def_doc_name + ' exists. Delete existing Global Definion Document?')
             if YesNo:
@@ -1616,9 +1617,9 @@ class _GlobalDefinitions():
 class _GlobalDefinition(_Elements, _Equations):
     def __init__(self, awrde, global_def_name: str):#-----------------------------------
         self.awrde = awrde
-        self._initialize_data_file(global_def_name)
+        self._initialize_global_def(global_def_name)
         #
-    def _initialize_data_file(self, global_def_name: str):#-------------------------------------
+    def _initialize_global_def(self, global_def_name: str):#-------------------------------------
         try:
             self._gd = self.awrde.Project.GlobalDefinitionDocuments(global_def_name)
         except:
@@ -1634,4 +1635,111 @@ class _GlobalDefinition(_Elements, _Equations):
         #    
 #
 #*****************************************************************************
+#
+class _OutputEquations():
+    '''
+    Methods for collection of Output Equations Documents
+    
+    Parameters
+    ----------
+    awrde: The AWRDE object returned from awrde_utils.establish_link()
+    '''
+    def __init__(self, awrde):#-----------------------------------------------
+        self.awrde = awrde
+        #
+    def _build_output_eqns_dict(self):#-----------------------------------------
+        '''
+        Create dictionary of all the output equation document names in the project
+        
+        Returns
+        -------
+        _output_eqns_dict: dict
+                            keys are the names of the output equations documents
+                            values are the output equation document objects
+        '''
+        self._output_eqns_dict = {}
+        for oe in self.awrde.Project.OutputEquationDocuments:
+            output_eqn = _OutputEquation(self.awrde, oe.Name)
+            self._output_eqns_dict[oe.Name] = output_eqn
+        #end for
+        #
+    @property
+    def output_equations_dict(self) -> dict:#---------------------------------
+        '''Returns output equations dictionary'''
+        self._build_output_eqns_dict()
+        return self._output_eqns_dict
+        #
+    @property
+    def output_equations_list(self) -> list:#-----------------------------------
+        '''Returns list of output equations documents names'''
+        output_eqs_list = list()
+        for oe in self.awrde.Project.OutputEquationDocuments:
+            output_eqs_list.append(oe.Name)
+        #end for
+        return output_eqs_list
+        #
+    def add_output_equations_document(self, output_eqn_doc_name):#----------------
+        oe_doc_exists = False
+        for oe in self.awrde.Project.OutputEquationDocuments:
+            if oe.Name == output_eqn_doc_name:
+                oe_doc_exists = True
+            #end if
+        #end for
+        #
+        if oe_doc_exists:
+            YesNo = messagebox.askyesno('Add Output Equations Document','Output Equations Document ' + output_eqn_doc_name + ' exists. Delete existing Output Equations Document?')
+            if YesNo:
+                self.remove_output_equations_document(output_eqn_doc_name)
+            else:
+                output_eqn_doc_name += ' 1'
+            #end if
+        #end if
+        #
+        try:
+            self.awrde.Project.OutputEquationDocuments.Add(output_eqn_doc_name)
+        except:
+            warnings.warn('Output Equations doc not added. Possible name conflict')
+        #end try
+        #
+    def remove_output_equations_document(self, output_eqn_doc_name):#---------------------------
+        output_eqn_doc_removed = False        
+        try:
+            for oe_idx in range(self.awrde.Project.OutputEquationDocuments.Count):
+                print(self.awrde.Project.OutputEquationDocuments[oe_idx].Name,'    ', output_eqn_doc_name)
+                if self.awrde.Project.OutputEquationDocuments[oe_idx].Name == output_eqn_doc_name:
+                    self.awrde.Project.OutputEquationDocuments.Remove(oe_idx+1)
+                    output_eqn_doc_removed = True
+                    break
+                #end if
+            #end for
+        except:
+            warnings.warn('remove_output_equations_document: Output Equations Document ' + output_eqn_doc_name + ' did not get removed')
+        #end try
+        return output_eqn_doc_removed
+        #
+        
+    
+#
+#*****************************************************************************
+#
+class _OutputEquation(_Equations):
+    def __init__(self, awrde, output_eqn_name:str):#----------------------------
+        self.awrde = awrde
+        self._initialize_output_eqn(output_eqn_name)
+        #
+    def _initialize_output_eqn(self, output_eqn_name):#--------------------------
+        try:
+            self._oe = self.awrde.Project.OutputEquationDocuments(output_eqn_name)
+        except:
+            raise RuntimeError('Output Equation Document does not exist: ' + output_eqn_name)
+        #end try
+        _Equations.__init__(self, self._oe)
+        #
+    @property
+    def output_eqn_name(self) -> str:#-----------------------------------------
+        '''Returns name of the output equation document'''
+        return self._oe.Name
+    
+#
+#*****************************************************************************
 #
\ No newline at end of file
